@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Filter and collate phase dataset in all subdirectories.
+Filter and collate search outputs in all subdirectories.
 
 Usage:
 
@@ -13,20 +13,20 @@ Example:
 """
 
 import os
-from os import path
 import zipfile
 from collections import defaultdict
+from os import path
 from shutil import rmtree
-from typing import List, Union, Iterator, Tuple
+from typing import List, Union, Iterator
 
-from .phase_output import PhaseOutput
 from .predicate import AttributePredicate
+from .search_output import SearchOutput
 
 
 class AggregatorGroup:
     def __init__(self, groups: ["AbstractAggregator"]):
         """
-        A group of aggregators produced by grouping phases on a field.
+        A group of aggregators produced by grouping search_outputs on a field.
 
         Parameters
         ----------
@@ -48,12 +48,7 @@ class AggregatorGroup:
         -------
         A collection of groups of the same length with each group having the same or fewer members.
         """
-        return AggregatorGroup(
-            [
-                group.filter(*predicates)
-                for group in self.groups
-            ]
-        )
+        return AggregatorGroup([group.filter(*predicates) for group in self.groups])
 
     def __getitem__(self, item):
         return self.groups[item]
@@ -75,50 +70,39 @@ class AggregatorGroup:
         -------
         A list of lists of values.
         """
-        return [
-            group.values(name)
-            for group in self.groups
-        ]
+        return [group.values(name) for group in self.groups]
 
 
 class AbstractAggregator:
-    def __init__(self, phases: List[PhaseOutput]):
+    def __init__(self, search_outputs: List[SearchOutput]):
         """
-        An aggregator that comprises several phases which matching filters.
+        An aggregator that comprises several search_outputs which matching filters.
 
         Parameters
         ----------
-        phases
-            Phases that were found to have matching filters
+        search_outputs
+            search_outputs that were found to have matching filters
         """
-        self.phases = phases
+        self.search_outputs = search_outputs
 
     def remove_unzipped(self):
         """
         Removes the unzipped output directory for each phase.
         """
-        for phase in self.phases:
-
+        for phase in self.search_outputs:
             split_path = path.split(phase.directory)[0]
 
             unzipped_path = path.join(split_path)
 
-            rmtree(
-                unzipped_path,
-                ignore_errors=True
-            )
+            rmtree(unzipped_path, ignore_errors=True)
 
     def __getitem__(
-            self,
-            item: Union[slice, int]
-    ) -> Union[
-        "AbstractAggregator",
-        PhaseOutput
-    ]:
+        self, item: Union[slice, int]
+    ) -> Union["AbstractAggregator", SearchOutput]:
         """
         If an index is passed in then a specific phase output is returned.
 
-        If a slice is passed in then an aggregator comprising several phases is returned.
+        If a slice is passed in then an aggregator comprising several search_outputs is returned.
 
         Parameters
         ----------
@@ -130,13 +114,11 @@ class AbstractAggregator:
         An aggregator or phase
         """
         if isinstance(item, slice):
-            return AbstractAggregator(
-                self.phases[item]
-            )
-        return self.phases[item]
+            return AbstractAggregator(self.search_outputs[item])
+        return self.search_outputs[item]
 
     def __len__(self):
-        return len(self.phases)
+        return len(self.search_outputs)
 
     def __getattr__(self, item):
         return AttributePredicate(item)
@@ -156,20 +138,20 @@ class AbstractAggregator:
 
         Returns
         -------
-        An aggregator comprising all phases that evaluate to `True` for all predicates.
+        An aggregator comprising all search_outputs that evaluate to `True` for all predicates.
         """
-        phases = self.phases
+        search_outputs = self.search_outputs
         for predicate in predicates:
-            phases = predicate.filter(phases)
-        phases = list(phases)
-        print(f"Filter found a total of {str(len(phases))} results")
-        return AbstractAggregator(phases=list(phases))
+            search_outputs = predicate.filter(search_outputs)
+        search_outputs = list(search_outputs)
+        print(f"Filter found a total of {str(len(search_outputs))} results")
+        return AbstractAggregator(search_outputs=list(search_outputs))
 
     def values(self, name: str) -> Iterator:
         """
         Get values from outputs with a given name.
 
-        A list the same length as the number of phases is returned
+        A list the same length as the number of search_outputs is returned
         where each item is the value of the attribute for a given
         phase.
 
@@ -184,51 +166,26 @@ class AbstractAggregator:
         -------
         A generator of values for the attribute
         """
-        return map(
-            lambda phase: getattr(
-                phase, name
-            ),
-            self.phases
-        )
+        return map(lambda phase: getattr(phase, name), self.search_outputs)
 
-    def homogenize(
-            self,
-            aggregator: "AbstractAggregator",
-            on: str
-    ) -> Tuple[
-        "AbstractAggregator",
-        "AbstractAggregator"
-    ]:
+    def child_values(self, name: str) -> Iterator[List]:
         """
-        Filter this aggregator and another aggregator such that each only
-        contain results where at least one result in the other aggregator
-        has the same value for a given property.
+        Get values with a given name from the child analyses of each search in
+        this aggregator.
 
         Parameters
         ----------
-        aggregator
-            Another aggregator to homogenize with this one.
-        on
-            The attribute of the underlying results which should match.
+        name
+            The name of an attribute expected to be associated with
+            child analysis output. If a pickle file with this name
+            is in the child analysis output directory then that pickle
+            will be loaded.
 
         Returns
         -------
-        A pair of aggregators with only matching results.
+        A generator of values for the attribute
         """
-        def _homogenize(a, b):
-            values = set(b.values(on))
-            return AbstractAggregator([
-                phase for phase in a.phases
-                if getattr(phase, on) in values
-            ])
-
-        return _homogenize(
-            self,
-            aggregator
-        ), _homogenize(
-            aggregator,
-            self
-        )
+        return (phase.child_values(name) for phase in self.search_outputs)
 
     def map(self, func):
         """
@@ -243,14 +200,11 @@ class AbstractAggregator:
         -------
         A generator of results
         """
-        return map(
-            func,
-            self.phases
-        )
+        return map(func, self.search_outputs)
 
     def group_by(self, field: str) -> AggregatorGroup:
         """
-        Group the phases by a field, e.g. pipeline.
+        Group the search_outputs by a field, e.g. pipeline.
 
         The object returned still permits filtering and attribute querying.
 
@@ -264,27 +218,23 @@ class AbstractAggregator:
         An object comprising lists of grouped fields
         """
         group_dict = defaultdict(list)
-        for phase in self.phases:
+        for phase in self.search_outputs:
             group_dict[getattr(phase, field)].append(phase)
         return AggregatorGroup(list(map(AbstractAggregator, group_dict.values())))
 
     @property
     def model_results(self) -> str:
         """
-        A string joining headers and results for all included phases.
+        A string joining headers and results for all included search_outputs.
         """
         return "\n\n".join(
             "{}\n\n{}".format(phase.header, phase.model_results)
-            for phase in self.phases
+            for phase in self.search_outputs
         )
 
 
 class Aggregator(AbstractAggregator):
-    def __init__(
-            self,
-            directory: str,
-            completed_only=False
-    ):
+    def __init__(self, directory: Union[str, os.PathLike], completed_only=False):
         """
         Class to aggregate phase results for all subdirectories in a given directory.
 
@@ -294,32 +244,39 @@ class Aggregator(AbstractAggregator):
         Parameters
         ----------
         directory
-            A directory in which the outputs of phases are kept. This is searched recursively.
+            A directory in which the outputs of search_outputs are kept. This is searched recursively.
         completed_only
-            If `True` only phases with a .completed file (indicating the phase was completed)
+            If `True` only search_outputs with a .completed file (indicating the phase was completed)
             are included in the aggregator.
         """
 
         # TODO : Progress bar here
 
-        print("Aggregator loading phases... could take some time.")
+        print("Aggregator loading search_outputs... could take some time.")
 
         self._directory = directory
-        phases = []
+        search_outputs = []
 
         for root, _, filenames in os.walk(directory):
             for filename in filenames:
                 if filename.endswith(".zip"):
-                    with zipfile.ZipFile(path.join(root, filename), "r") as f:
-                        f.extractall(path.join(root, filename[:-4]))
+                    try:
+                        with zipfile.ZipFile(path.join(root, filename), "r") as f:
+                            f.extractall(path.join(root, filename[:-4]))
+                    except zipfile.BadZipFile:
+                        raise zipfile.BadZipFile(
+                            f"File is not a zip file: \n " f"{root} \n" f"{filename}"
+                        )
 
         for root, _, filenames in os.walk(directory):
             if "metadata" in filenames:
                 if not completed_only or ".completed" in filenames:
-                    phases.append(PhaseOutput(root))
+                    search_outputs.append(SearchOutput(root))
 
-        if len(phases) == 0:
-            print(f"\nNo phases found in {directory}\n")
+        if len(search_outputs) == 0:
+            print(f"\nNo search_outputs found in {directory}\n")
         else:
-            print(f"\n A total of {str(len(phases))} phases and results were found.")
-        super().__init__(phases)
+            print(
+                f"\n A total of {str(len(search_outputs))} search_outputs and results were found."
+            )
+        super().__init__(search_outputs)
