@@ -1,8 +1,8 @@
 from autofit.mapper.prior.arithmetic import ArithmeticMixin
-from autofit.mapper.prior_model.prior_model import PriorModel, Prior
+from autofit.mapper.prior_model.prior_model import Model, Prior
 
 
-class AnnotationPriorModel(PriorModel, ArithmeticMixin):
+class AnnotationPriorModel(Model, ArithmeticMixin):
     def __init__(self, cls, parent_class, true_argument_name, **kwargs):
         self.parent_class = parent_class
         self.true_argument_name = true_argument_name
