@@ -4,28 +4,28 @@ from autofit.text import formatter as frm
 
 logger = logging.getLogger(__name__)
 
-
 def values_from_samples(samples, median_pdf_model):
 
     if median_pdf_model:
-        return samples.median_pdf_vector
-    return samples.max_log_likelihood_vector
+        return samples.median_pdf(as_instance=False)
+    return samples.max_log_likelihood(as_instance=False)
 
 
 def summary(
     samples, sigma=3.0, median_pdf_model=True, indent=1, line_length=None
 ) -> str:
-    """ Create a string summarizing the results of the `NonLinearSearch` at an input sigma value.
+    """
+    Create a string summarizing the results of the `NonLinearSearch` at an input sigma value.
 
     This function is used for creating the model.results files of a non-linear search.
 
     Parameters
     ----------
-    sigma : float
+    sigma
         The sigma within which the PDF is used to estimate errors (e.g. sigma = 1.0 uses 0.6826 of the PDF)."""
 
     values = values_from_samples(samples=samples, median_pdf_model=median_pdf_model)
-    values_at_sigma = samples.vector_at_sigma(sigma=sigma)
+    values_at_sigma = samples.values_at_sigma(sigma=sigma, as_instance=False)
 
     parameter_names = samples.model.parameter_names
 
@@ -42,23 +42,33 @@ def summary(
             values_at_sigma=values_at_sigma[i],
         )
 
-        sigma_formatter.add((prior_path, value_result))
+        sigma_formatter.add(prior_path, value_result)
 
-    return "\n\nSummary ({} sigma limits):\n\n{}".format(sigma, sigma_formatter.text)
+    return f"\n\nSummary ({sigma} sigma limits):\n\n{sigma_formatter.text}"
 
 
-def latex(samples, median_pdf_model=True, sigma=3.0, name_to_label=True) -> str:
-    """ Create a string summarizing the results of the `NonLinearSearch` at an input sigma value.
+def latex(
+        samples,
+        median_pdf_model=True,
+        sigma=3.0,
+        name_to_label=True,
+        include_name=True,
+        include_quickmath=False,
+        prefix="",
+        suffix=""
+) -> str:
+    """
+    Create a string summarizing the results of the `NonLinearSearch` at an input sigma value.
 
     This function is used for creating the model.results files of a non-linear search.
 
     Parameters
     ----------
-    sigma : float
+    sigma
         The sigma within which the PDF is used to estimate errors (e.g. sigma = 1.0 uses 0.6826 of the PDF)."""
 
     values = values_from_samples(samples=samples, median_pdf_model=median_pdf_model)
-    errors_at_sigma = samples.error_vector_at_sigma(sigma=sigma)
+    errors_at_sigma = samples.errors_at_sigma(sigma=sigma, as_instance=False)
 
     table = []
 
@@ -68,12 +78,14 @@ def latex(samples, median_pdf_model=True, sigma=3.0, name_to_label=True) -> str:
             parameter_name=samples.model.parameter_names[i],
             value=values[i],
             errors=errors_at_sigma[i],
-            subscript=samples.model.subscripts[i],
+            superscript=samples.model.superscripts[i],
             name_to_label=name_to_label,
+            include_name=include_name,
+            include_quickmath=include_quickmath
         )
 
         table.append(f"{label_value}")
 
     table = "".join(table)[:-3]
 
-    return "{}".format(table)
+    return f"{prefix}{table}{suffix}"
